@@ -13,22 +13,18 @@
 ##############################################################################
 """Helper file used to launch a ZEO server cross platform"""
 
-import os
-import sys
-import time
+import asyncore
 import errno
 import getopt
-import socket
-import signal
-import asyncore
-import threading
 import logging
-
-import ThreadedAsync.LoopCallback
-
-from ZEO.StorageServer import StorageServer
-from ZEO.runzeo import ZEOOptions
-
+import os
+import signal
+import socket
+import sys
+import threading
+import time
+import ZEO.runzeo
+import ZEO.zrpc.connection
 
 def cleanup(storage):
     # FileStorage and the Berkeley storages have this method, which deletes
@@ -71,7 +67,10 @@ class ZEOTestServer(asyncore.dispatcher):
         # Count down to zero, the number of connects
         self._count = 1
         self._label ='%d @ %s' % (os.getpid(), addr)
-        self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
+        if isinstance(addr, str):
+            self.create_socket(socket.AF_UNIX, socket.SOCK_STREAM)
+        else:
+            self.create_socket(socket.AF_INET, socket.SOCK_STREAM)
         # Some ZEO tests attempt a quick start of the server using the same
         # port so we have to set the reuse flag.
         self.set_reuse_addr()
@@ -127,7 +126,7 @@ class Suicide(threading.Thread):
         # The client threads in the ConcurrentUpdate tests will run for
         # as long as 300 seconds.  Set this timeout to 330 to minimize
         # chance that the server gives up before the clients.
-        time.sleep(330)
+        time.sleep(999)
         log(str(os.getpid()), "suicide thread invoking shutdown")
 
         # If the server hasn't shut down yet, the client may not be
@@ -155,61 +154,59 @@ def main():
     # wrong, it's a bug in the test suite.
     keep = 0
     configfile = None
+    suicide = True
     # Parse the arguments and let getopt.error percolate
-    opts, args = getopt.getopt(sys.argv[1:], 'kC:')
+    opts, args = getopt.getopt(sys.argv[1:], 'dkSC:v:')
     for opt, arg in opts:
         if opt == '-k':
             keep = 1
+        if opt == '-d':
+            ZEO.zrpc.connection.debug_zrpc = True
         elif opt == '-C':
             configfile = arg
+        elif opt == '-S':
+            suicide = False
+        elif opt == '-v':
+            ZEO.zrpc.connection.Connection.current_protocol = arg
 
-    zo = ZEOOptions()
+    zo = ZEO.runzeo.ZEOOptions()
     zo.realize(["-C", configfile])
-    zeo_port = int(zo.address[1])
+    addr = zo.address
 
     if zo.auth_protocol == "plaintext":
-        import ZEO.tests.auth_plaintext
+        __import__('ZEO.tests.auth_plaintext')
 
-    # Open the config file and let ZConfig parse the data there.  Then remove
-    # the config file, otherwise we'll leave turds.
-    # The rest of the args are hostname, portnum
-    test_port = zeo_port + 1
-    test_addr = ('localhost', test_port)
-    addr = ('localhost', zeo_port)
+    if isinstance(addr, tuple):
+        test_addr = addr[0], addr[1]+1
+    else:
+        test_addr = addr + '-test'
     log(label, 'creating the storage server')
     storage = zo.storages[0].open()
     mon_addr = None
     if zo.monitor_address:
         mon_addr = zo.monitor_address
-    server = StorageServer(
-        zo.address,
-        {"1": storage},
-        read_only=zo.read_only,
-        invalidation_queue_size=zo.invalidation_queue_size,
-        transaction_timeout=zo.transaction_timeout,
-        monitor_address=mon_addr,
-        auth_protocol=zo.auth_protocol,
-        auth_database=zo.auth_database,
-        auth_realm=zo.auth_realm)
+    server = ZEO.runzeo.create_server({"1": storage}, zo)
 
     try:
         log(label, 'creating the test server, keep: %s', keep)
         t = ZEOTestServer(test_addr, server, keep)
     except socket.error, e:
-        if e[0] <> errno.EADDRINUSE: raise
+        if e[0] != errno.EADDRINUSE:
+            raise
         log(label, 'addr in use, closing and exiting')
         storage.close()
         cleanup(storage)
         sys.exit(2)
 
     t.register_socket(server.dispatcher)
-    # Create daemon suicide thread
-    d = Suicide(test_addr)
-    d.setDaemon(1)
-    d.start()
+    if suicide:
+        # Create daemon suicide thread
+        d = Suicide(test_addr)
+        d.setDaemon(1)
+        d.start()
     # Loop for socket events
-    log(label, 'entering ThreadedAsync loop')
-    ThreadedAsync.LoopCallback.loop()
+    log(label, 'entering asyncore loop')
+    asyncore.loop()
 
 
 if __name__ == '__main__':
